The core modules of the generative visual framework (GVF) for the
scsys-io platform.
Modules
- error
- this module defines the
Errortype for thegvfframework, enumerating various errors types that commonly occur within the framework. - traits
- the core traits for the visual framework, establishing common interfaces for various widgets, layouts, and other components.
Enums
- Error
- The
Errortype for thegvfframework, enumerating various error types that commonly occur within the framework.