Module error

Module error 

this module defines the Error type for the gvf framework, enumerating various errors types that commonly occur within the framework.

Enums

Error
The Error type for the gvf framework, enumerating various error types that commonly occur within the framework.

Type Aliases

Result
a type alias for Result that uses the custom Error type