this module defines the Error type for the gvf framework, enumerating various
errors types that commonly occur within the framework.
Enums
- Error
- The
Errortype for thegvfframework, enumerating various error types that commonly occur within the framework.